@@ -62,7 +62,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
     metadata = metadata_module.PrimitiveMetadata({
         'id': '69845479-0b61-3578-b382-972cd0e61d69',
-        'version': '2.0.16',
+        'version': '2.0.17',
         'name': 'IPCMB feature selector',
         'keywords': ['rpi primitives'],
         'source': {
@@ -71,10 +71,10 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         'installation':[{
             'type': 'PIP',
             'package': 'rpi_featureSelection_python_tools',
-	    'version': '2.0.16'
+	    'version': '2.0.17'
         }],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.IPCMBplus_Selector',
-        'algorithm_types': 'MINIMUM_REDUNDANCY_FEATURE_SELECTION',
+        'algorithm_types': ['MINIMUM_REDUNDANCY_FEATURE_SELECTION'],
         'primitive_family': 'FEATURE_SELECTION',
         'preconditions': [
             "NO_CATEGORICAL_VALUES",
